@@ -17,6 +17,7 @@
 #include <QStandardPaths>
 #include <QDateTime>
 #include <QRegularExpression>
+#include <QLoggingCategory>
 #include <qmath.h>
 
 #ifdef Q_OS_LINUX
@@ -37,6 +38,12 @@ static inline bool inTest()
 
 DCORE_BEGIN_NAMESPACE
 
+#ifdef QT_DEBUG
+Q_LOGGING_CATEGORY(logSysInfo, "dtk.dsysinfo")
+#else
+Q_LOGGING_CATEGORY(logSysInfo, "dtk.dsysinfo", QtInfoMsg)
+#endif
+
 class Q_DECL_HIDDEN DSysInfoPrivate
 {
 public:
@@ -86,7 +93,14 @@ public:
     struct OSBuild {
         OSBuild():A(0), B(0), C(0), D(0), xyz(100){
         }
-        uint A, B, C, D, E, xyz; // ABCDE.xyz
+
+        /* ABCDE.xyz模式
+        系统构建号 	A                       B           C           D           E         x        yz
+        值含义	操作系统产品的大版本代号	产品线类型	功能小版本	产品线版本	处理器架构	固定值	补丁小版本
+        值位数     1                         1           1           1           1         1        2
+        值范围   -------------------------	0～9、A~Z	---------------------------       1	   00~99，AA~ZZ
+        */
+        uint A, B, C, D, E, xyz;
     };
 
     MinVersion minVersion;
@@ -132,9 +146,12 @@ bool DSysInfoPrivate::splitA_BC_DMode()
         minVersion.D = minv % 10;
     } else if (minorVersion.length() > 0) {
         const QString D = minorVersion.right(1);
-        if (D.contains(QRegularExpression("[0-9A-Z]"))) {
-            // 0-9...A-Z
-            minVersion.D = 10 + static_cast<uint>(D.data()->toLatin1() - 'A');
+        const QChar ch = D.at(0);
+        if (ch.isDigit()) {
+            minVersion.D = static_cast<uint>(ch.unicode() - '0');
+        } else if (ch >= 'A' && ch <= 'Z') {
+            // 0-9...A-Z -> 10..35
+            minVersion.D = 10 + static_cast<uint>(ch.unicode() - 'A');
         } else {
             qWarning() << "invalid minorVersion";
             minVersion.D = 0;
@@ -150,7 +167,7 @@ bool DSysInfoPrivate::splitA_BC_DMode()
 
 void DSysInfoPrivate::ensureDeepinInfo()
 {
-    if (static_cast<int>(deepinType) >= 0 && !inTest())
+    if (static_cast<int>(deepinType) > 0 && !inTest())
         return;
 
     if (inTest())
@@ -220,6 +237,8 @@ void DSysInfoPrivate::ensureDeepinInfo()
         deepinType = DSysInfo::DeepinServer;
     } else if (deepin_type == "Personal") {
         deepinType = DSysInfo::DeepinPersonal;
+    } else if (deepin_type == "Military") {
+        deepinType = DSysInfo::DeepinMilitary;
     } else {
         deepinType = DSysInfo::UnknownDeepin;
     }
@@ -257,19 +276,24 @@ bool DSysInfoPrivate::ensureOsVersion()
     D_ASSET_EXIT(left.size() == 5, "OsBuild version(ls) invalid!");
 
     int idx = 0;
-    osBuild.A = left.value(idx++, "0").toUInt(&ok);
+    auto parseDigitOrAZ = [&](const QString &s, bool *outOk) -> uint {
+        if (s.isEmpty()) { if (outOk) *outOk = false; return 0u; }
+        const QChar ch = s.at(0);
+        if (ch.isDigit()) { if (outOk) *outOk = true; return static_cast<uint>(ch.unicode() - '0'); }
+        if (ch >= 'A' && ch <= 'Z') { if (outOk) *outOk = true; return static_cast<uint>(ch.toLatin1()); }
+        if (outOk) *outOk = false;
+        return 0u;
+    };
+
+    osBuild.A = parseDigitOrAZ(left.value(idx++, "0"), &ok);
     D_ASSET_EXIT(ok, "OsBuild version(A) invalid!");
-    osBuild.B = left.value(idx++, "0").toUInt(&ok);
+    osBuild.B = parseDigitOrAZ(left.value(idx++, "0"), &ok);
     D_ASSET_EXIT(ok, "OsBuild version(B) invalid!");
-    osBuild.C = left.value(idx++, "0").toUInt(&ok);
-    if (!ok) {
-        auto c = left.value(idx-1, "0").toLatin1();
-        D_ASSET_EXIT(c.size()>0, "OsBuild version(C) invalid!");
-        osBuild.C = uint(c.at(0));
-    }
-    osBuild.D = left.value(idx++, "0").toUInt(&ok);
+    osBuild.C = parseDigitOrAZ(left.value(idx++, "0"), &ok);
+    D_ASSET_EXIT(ok, "OsBuild version(C) invalid!");
+    osBuild.D = parseDigitOrAZ(left.value(idx++, "0"), &ok);
     D_ASSET_EXIT(ok, "OsBuild version(D) invalid!");
-    osBuild.E = left.value(idx++, "0").toUInt(&ok);
+    osBuild.E = parseDigitOrAZ(left.value(idx++, "0"), &ok);
     D_ASSET_EXIT(ok, "OsBuild version(E) invalid!");
 
     // xyz
@@ -423,7 +447,7 @@ static bool readLsbRelease(DSysInfoPrivate *info)
 
 void DSysInfoPrivate::ensureReleaseInfo()
 {
-    if (productType >= 0 && !inTest()) {
+    if (productType > 0 && !inTest()) {
         return;
     }
 
@@ -655,6 +679,7 @@ DSysInfo::UosEdition DSysInfo::uosEditionType()
         case 3:
             return UosCommunity;
         case 4:
+        case 9:
             return UosMilitary;
         case 5:
             return UosDeviceEdition;
@@ -675,6 +700,10 @@ DSysInfo::UosEdition DSysInfo::uosEditionType()
             return UosMilitaryS;
         case 5:
             return UosDeviceEdition;
+        case 9:
+            return UosEducation; // 服务器 教育版(UT-3-PP-PR-001_操作系统标识与产品版本号规范_20250905)
+        case 'A':
+            return UosDefense; // 服务器 国防版
         default:
             break;
         }
@@ -1122,18 +1151,35 @@ qint64 DSysInfo::memoryInstalledSize()
         }
 
         const QByteArray &lshwInfoJson = lshw.readAllStandardOutput();
-        QJsonArray lshwResultArray = QJsonDocument::fromJson(lshwInfoJson).array();
-        if (!lshwResultArray.isEmpty()) {
-            QJsonValue memoryHwInfo = lshwResultArray.first();
-            QString id = memoryHwInfo.toObject().value("id").toString();
-            Q_ASSERT(id == "memory");
-            siGlobal->memoryInstalledSize = memoryHwInfo.toObject().value("size").toDouble(); // TODO: check "units" is "bytes" ?
+
+        QJsonParseError error;
+        auto doc = QJsonDocument::fromJson(lshwInfoJson, &error);
+        if (error.error != QJsonParseError::NoError) {
+            qCWarning(logSysInfo(), "parse failed, expect json doc from lshw command");
+            return -1;
+        }
+
+        if (!doc.isArray()) {
+            qCWarning(logSysInfo(), "parse failed, expect array");
+            return -1;
+        }
+
+        QJsonArray lshwResultArray = doc.array();
+        for (const QJsonValue value : lshwResultArray) {
+            QJsonObject obj = value.toObject();
+            if (obj.contains("id") && obj.value("id").toString() == "memory") {
+                siGlobal->memoryInstalledSize = obj.value("size").toDouble(); // TODO: check "units" is "bytes" ?
+                break;
+            }
         }
     }
 
+    Q_ASSERT(siGlobal->memoryInstalledSize > 0);
+
     return siGlobal->memoryInstalledSize;
-#endif
+#else
     return -1;
+#endif
 }
 
 /*!
